summaryrefslogtreecommitdiff
path: root/whole.c
diff options
context:
space:
mode:
authorMartin Pool <mbp@sourcefrog.net>2001-02-26 13:27:49 +0000
committerMartin Pool <mbp@sourcefrog.net>2001-02-26 13:27:49 +0000
commit315ffd056334b1465efed061468f48110649697b (patch)
treee2b0056cdaa6edb2030b0f88471f4b275a519c54 /whole.c
parent735619089c57072ee6c26e35352108067ed78980 (diff)
downloadlibrsync-315ffd056334b1465efed061468f48110649697b.tar.gz
Rename HS_OK to HS_DONE and HS_RUN_OK to HS_RUNNING to be more
descriptive.
Diffstat (limited to 'whole.c')
-rw-r--r--whole.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/whole.c b/whole.c
index 7857788..284a194 100644
--- a/whole.c
+++ b/whole.c
@@ -59,7 +59,7 @@
* \param in_file Source of input bytes, or NULL if the input buffer
* should not be filled.
*
* \return HS_OK if the job completed, or otherwise an error result.
*/
hs_result
hs_whole_run(hs_job_t *job, FILE *in_file, FILE *out_file)
@@ -78,20 +78,20 @@ hs_whole_run(hs_job_t *job, FILE *in_file, FILE *out_file)
do {
if (in_fb) {
iores = hs_infilebuf_fill(in_fb, &ending);
- if (iores != HS_OK)
+ if (iores != HS_DONE)
return iores;
}
result = hs_job_iter(job, ending);
- if (result != HS_OK && result != HS_BLOCKED)
+ if (result != HS_DONE && result != HS_BLOCKED)
return result;
if (out_fb) {
iores = hs_outfilebuf_drain(out_fb);
- if (iores != HS_OK)
+ if (iores != HS_DONE)
return iores;
}
- } while (result != HS_OK);
+ } while (result != HS_DONE);
/* FIXME: At the moment we leak if there's an IO error. That's no
* good. */
@@ -59,7 +59,7 @@
* should not be filled.
*
- * \return HS_OK if the job completed, or otherwise an error result.
+ * \return HS_DONE if the job completed, or otherwise an error result.
*/
hs_result